Struct DisableBlinking
pub struct DisableBlinking;Available on crate feature
term only.Expand description
A command that disables blinking of the terminal cursor.
Notes
- Some Unix terminals (ex: GNOME and Konsole) as well as Windows versions lower than Windows 10 do not support this functionality.
Use
SetCursorStylefor better cross-compatibility. - Commands must be executed/queued for execution otherwise they do nothing.