Struct MoveToNextLine
pub struct MoveToNextLine(pub u16);Available on crate feature
term only.Expand description
A command that moves the terminal cursor down the given number of lines, and moves it to the first column.
Notes
- This command is 1 based, meaning
MoveToNextLine(1)moves to the next line. - Most terminals default 0 argument to 1.
- Commands must be executed/queued for execution otherwise they do nothing.
Tuple Fields
0: u16Trait Implementations
impl Clone for MoveToNextLine
impl Clone for MoveToNextLine
fn clone(&self) -> MoveToNextLine
fn clone(&self) -> MoveToNextLine
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Command for MoveToNextLine
impl Command for MoveToNextLine
impl Copy for MoveToNextLine
impl Debug for MoveToNextLine
impl Debug for MoveToNextLine
impl Display for MoveToNextLine
impl Display for MoveToNextLine
impl Eq for MoveToNextLine
impl PartialEq for MoveToNextLine
impl PartialEq for MoveToNextLine
impl StructuralPartialEq for MoveToNextLine